@@ -27,7 +27,6 @@ from oct2py import Oct2Py, Oct2PyError
 from oct2py.utils import Struct
 from oct2py.compat import unicode, long, StringIO
 
-
 octave = Oct2Py()
 octave.addpath(os.path.dirname(__file__))
 DATA = octave.test_datatypes()
@@ -59,6 +58,19 @@ TYPE_CONVERSIONS = [(int, 'int32', np.int32),
                 (np.complex128, 'double', np.complex128), ]
 
 
+if not os.name == 'nt':
+    # needed for testing support
+    if not hasattr(sys.stdout, 'buffer'):  # pragma: no cover
+        class Dummy(object):
+
+            def write(self):
+                pass
+        try:
+            sys.stdout.buffer = Dummy()
+        except AttributeError:
+            pass
+
+
 def test_python_conversions():
     """Test roundtrip python type conversions
     """
@@ -662,7 +674,7 @@ class BasicUsageTest(test.TestCase):
         oc = Oct2Py()
         self.assertRaises(Oct2PyError, oc._eval, "a=1++3")
 
-        if not oc._session.use_pexpect:
+        if os.name == 'nt':
             self.assertRaises(Oct2PyError, oc._eval, "a=1")
         else:
             oc.put('a', 1)
@@ -803,7 +815,6 @@ def test_using_closed_session():
 
 
 def test_keyboard():
-
     oc = Oct2Py()
 
     oc._eval('a=1')
@@ -811,13 +822,17 @@ def test_keyboard():
     stdin = sys.stdin
     stdout = sys.stdout
     output = StringIO()
-    sys.stdin = StringIO('a\nreturn')
+    sys.stdin = StringIO('a\nexit')
     oc._session.stdout = output
     try:
         oc.keyboard(timeout=3)
-    except Oct2PyError as e:
+    except Oct2PyError as e:  # pragma: no cover
         if 'session timed out' in str(e).lower():
+            # the keyboard command is not supported
+            # (likely using Octave 3.2)
             return
+        else:
+            raise(e)
     sys.stdin.flush()
     sys.stdin = stdin
     oc._session.stdout = stdout
@@ -857,7 +872,7 @@ def test_call_path():
     path = os.path.join(os.path.dirname(__file__), 'test_datatypes.m')
     DATA = oc.call(path)
     assert DATA.string.basic == 'spam'
-    
+
 
 def test_long_variable_name():
     oc = Oct2Py()
@@ -867,6 +882,14 @@ def test_long_variable_name():
     assert x == 1
 
 
+def test_syntax_error_embedded():
+    oc = Oct2Py()
+    test.assert_raises(Oct2PyError, oc.run, """eval("a='1")""")
+    oc.put('b', 1)
+    x = oc.get('b')
+    assert x == 1
+
+
 if __name__ == '__main__':  # pragma: no cover
     print('oct2py test')
     print('*' * 20)
